function [u0,u,P0] = SPDsolve(K0,K,P,cDOF,cDOFasc,nn)
//Solve symmetric positive definite system from CEMEF-UTN
//Calling Sequence
// [u0, u, P0] = SPDsolve(K0, K, P, cDOF, cDOFasc, nn)
//
//Parameters
// K0: Complete stiffness matrix of the structure [DOFn*nn x DOFn*nn]     
// K: Active stiffness matrix of the structure (reduced to active DOF) [DOFn*nn-cDOF x DOFn*nn-cDOF]
// P: Nodal external loads vector (reduced to active DOF) [DOFn*nn-cDOF x 1]
// cDOF: Constrained degrees of freedom vector (descending order) [cDOF x 1]
// cDOFasc: Constrained degrees of freedom vector (ascending order) [cDOF x 1]
// nn: Number of nodes [1 x 1]
//
// OUTPUT ARGUMENTS:
// u0: Complete nodal displacements vector [DOFn*nn x 1]
// u: Active nodal displacements vector (reduced to active DOF) [DOFn*nn-cDOF x 1]
// P0: Complete nodal loads vector [DOFn*nn x 1]
//
// See also
// assemb3d
// bc
// inpbar3d
// preplottruss3d
// postplottruss3d
// SPDverif
// stiffbar3d
// stressbar3d
//
// Authors
// CEMEF-UTN v1.1-6; Grupo de Simulacion y Mecanica Computacional, 
//   Universidad Tecnologica Nacional, Facultad Regional Haedo
//   Copyright 2010 UTN FRH GSMC
//   $Revision: //REV 1.1.1 2010/11/26 by MCR

  // SPDSOLVE ---> SOLVE SYMMETRIC POSSITIVE DEFINITE SYSTEM FROM CEMEF-UTN
  //
  // SYNTAX:
  // [u0,u,P0]=SPDsolve(K0,K,P,cDOF,cDOFasc,nn)
  // - Type: Function
  //
  // INPUT ARGUMENTS:
  // - K0: Complete stiffness matrix of the structure [DOFn*nn x DOFn*nn]     
  // - K: Active stiffness matrix of the structure (reduced to active DOF) 
  //       [DOFn*nn-cDOF x DOFn*nn-cDOF]
  // - P: Nodal external loads vector (reduced to active DOF) 
  //       [DOFn*nn-cDOF x 1]
  // - cDOF: Constrained degrees of freedom vector (descending order) 
  //          [cDOF x 1]
  // - cDOFasc: Constrained degrees of freedom vector (ascending order)
  //             [cDOF x 1]
  // - nn: Number of nodes [1 x 1]
  //
  // OUTPUT ARGUMENTS:
  // - u0: Complete nodal displacements vector [DOFn*nn x 1]
  // - u: Active nodal displacements vector (reduced to active DOF)
  //       [DOFn*nn-cDOF x 1]
  // - P0: Complete nodal loads vector [DOFn*nn x 1]
  //
  // CEMEF-UTN v1.1-6
  // Grupo de Simulacion y Mecanica Computacional
  // Universidad Tecnologica Nacional
  // Facultad Regional Haedo
  //
  //   Copyright 2010 UTN FRH GSMC
  //   $Revision: //REV 1.1.5 2010/11/26 by MCR
  
  SPDverif(K0,cDOFasc,K)//REV 1.6 2010/06/31 ---START SPD MATRIX VERIFICATION-
  // DISPLACEMENTS COMPUTATION
  // Nodal active displacements vector (reduced to active dofs)
  u=K\P; //REV 1.6 2010/06/31 Changed internal solver technique
  // =========================================================================
  // Nodal displacements vector (expansion to all dofs)
  // =========================================================================
  u0=zeros(3*nn,1);
  contz=0;
  for DOF=1:3*nn
    for j=1:max(size(cDOF))
      b=0;
      if DOF~=cDOF(j)
        continue
      else
        b=1;break
      end
    end
    if b==0
      u0(DOF)=u(DOF-contz);
    else 
      u0(DOF)=0;
      contz=contz+1;
    end
  end
  // =========================================================================
  // Nodal loads vector (external forces and reactions)
  // =========================================================================
  P0=K0*u0;
endfunction
//Translated by LBD 2010/11/15



