function [tc,K0]=assemb3d(elem,DOFn,DOFe,kG,nn,ne)
// Table of connectivity and asssembly process
//Calling Sequence
// [tc, K0] = assemb3d(elem, DOFn, DOFe, kG, nn, ne)
//
//Parameters
// INPUT ARGUMENTS:
// elem: Table of elements [ne x 9]
// DOFn: Number of DOFs per node (global coordinate system) [1 x 1]
// DOFe: Number of DOFs per element (global coordinate system) [1 x 1]
// kG: Global stiffness matrix [ne*6 x 6]
// nn: Number of nodes [1 x 1]
// ne: Number of elements [1 x 1]
//
// OUTPUT ARGUMENTS:
// tc: Table of connectivity [ne*DOFe x 3]
// K0: Complete stiffness matrix of the structure [DOFn*nn x DOFn*nn]
//
// See also
// bc
// inpbar3d
// preplottruss3d
// postplottruss3d
// SPDsolve
// SPDverif
// stiffbar3d
// stressbar3d
//
// Authors
// CEMEF-UTN v1.1-6
// Grupo de Simulacion y Mecanica Computacional
// Universidad Tecnologica Nacional
// Facultad Regional Haedo
//
//   Copyright 2010 UTN FRH GSMC
//   $Revision: //REV 1.1.6 2010/11/26 by MCR

  // ----------------------------------------------------------------------
  // ASSEMB3D ---> TABLE OF CONNECTIVITY AND ASSSEMBLY PROCESS
  //
  // SYNTAX:
  // [tc,K0]=assemb3d(elem,DOFn,DOFe,kG,nn,ne)
  // - Type: Function
  //
  // INPUT ARGUMENTS:
  // - elem: Table of elements [ne x 9]
  // - DOFn: Number of DOFs per node (global coordinate system) [1 x 1]
  // - DOFe: Number of DOFs per element (global coordinate system) [1 x 1]
  // - kG: Global stiffness matrix [ne*6 x 6]
  // - nn: Number of nodes [1 x 1]
  // - ne: Number of elements [1 x 1]
  //
  // OUTPUT ARGUMENTS:
  // - tc: Table of connectivity [ne*DOFe x 3]
  // - K0: Complete stiffness matrix of the structure [DOFn*nn x DOFn*nn]
  //
  // CEMEF-UTN v1.1-6
  // Grupo de Simulacion y Mecanica Computacional
  // Universidad Tecnologica Nacional
  // Facultad Regional Haedo
  //
  //   Copyright 2010 UTN FRH GSMC
  //   $Revision: //REV 1.1.6 2010/11/26 by MCR
  
  gcl=(1:DOFe)';
  tc=zeros(DOFe*ne,3);
  K0=zeros(DOFn*nn,DOFn*nn);
  for e=1:ne
    // =====================================================================
    // TABLE OF CONNECTIVITY
    // =====================================================================
    // Element designation
    tc(DOFe*e-(DOFe-1):DOFe*e,1)=e*ones(DOFe,1);
    // Local grades of connectivity
    tc(DOFe*e-(DOFe-1):DOFe*e,2)=gcl;
    // Global grades of connectivity
    for i=1:DOFn
      // Initial node (n0) 
      tc(DOFe*e-(DOFe-i),3)=3*elem(e,2)-(DOFn-i); 
      // e.g. 3D BAR ELEMENT: 5,4,3={DOFe-i} and 2,1,0={DOFn-i}
      //               tc(6*e-5,3)=3*elem(e,2)-2;
      //               tc(6*e-4,3)=3*elem(e,2)-1;
      //               tc(6*e-3,3)=3*elem(e,2)-0;
      // Final node (nf)
      tc(DOFe*e-(DOFn-i),3)=3*elem(e,3)-(DOFn-i); 
      // e.g. 3D BAR ELEMENT: 2,1,0={DOFn-i} and 2,1,0={DOFn-i}
      //               tc(6*e-2,3)=3*elem(e,3)-2; //REV 1.1.6 by MCR
      //               tc(6*e-1,3)=3*elem(e,3)-1; //REV 1.1.6 by MCR
      //               tc(6*e-0,3)=3*elem(e,3)-0; //REV 1.1.6 by MCR
    end
    // =====================================================================
    // ASSSEMBLY PROCESS: Complete stiffness matrix of the structure
    // =====================================================================
    K0(tc(DOFe*e-(DOFe-1):DOFe*e,3),tc(DOFe*e-(DOFe-1):DOFe*e,3))=..
    K0(tc(DOFe*e-(DOFe-1):DOFe*e,3),tc(DOFe*e-(DOFe-1):DOFe*e,3))..
    +kG(DOFe*e-(DOFe-1):DOFe*e,gcl); //REV 1.1.2 MCR: BUG FIXED
  end
endfunction
//Translated by SDL 2010/09/19





