function [M,nod,elem,E,A,L,dircos,nn,ne]=inpbar3d(filename)
// Data migration and geometric and mechanical properties computation (3D bar element)
//Calling Sequence
// [M, nod, elem, E, A, L, dircos, nn, ne] = inpbar3d(filename)
//
//Parameters
// filename: File name of input data. (Path and) extension must be included
// 
// OUTPUT ARGUMENTS:
// M: Data importation matrix (structured) 
// nod: Table of nodes [nn x 3] 
// elem: Table of elements [ne x 9]
// E: Modulus of elasticity [ne x 1]
// A: Cross-sectional Area [ne x 1]
// L: Bar length [ne x 1]
// dircos: Direction cosines [ne x 3]
// nn: Number of nodes [1 x 1]
// ne: Number of elements [1 x 1]
//
// See also
// assemb3d
// bc
// inpbar3d
// preplottruss3d
// postplottruss3d
// SPDsolve
// SPDverif
// stiffbar3d
// stressbar3d
//
// Authors
// CEMEF-UTN v1.1-6; Grupo de Simulacion y Mecanica Computacional, Universidad Tecnologica Nacional, Facultad Regional Haedo
//   Copyright 2010 UTN FRH GSMC
//   $Revision: //REV 1.1.5 2010/11/26 by MCR

  // -----------------------------------------------------------------------
  // INPBAR3D ---> DATA MIGRATION AND GEOMETRIC AND MECHANICAL PROPERTIES
  // COMPUTATION (3D BAR ELEMENT)
  // 
  // SYNTAX:
  // [M,nod,elem,E,A,L,dircos,nn,ne]=inpbar3d(filename)
  // - Type: Function
  //
  // INPUT ARGUMENTS:
  // - filename: File name of input data. Extension must be included
  //          - String. Must be entered between ''
  // 
  // OUTPUT ARGUMENTS:
  // - M: Data importation matrix (structured) 
  // - nod: Table of nodes [nn x 3] 
  // - elem: Table of elements [ne x 9]
  // - E: Modulus of elasticity [ne x 1]
  // - A: Cross-sectional Area [ne x 1]
  // - L: Bar length [ne x 1]
  // - dircos: Direction cosines [ne x 3]
  // - nn: Number of nodes [1 x 1]
  // - ne: Number of elements [1 x 1]
  //
  // CEMEF-UTN v1.1-6
  // Grupo de Simulacion y Mecanica Computacional
  // Universidad Tecnologica Nacional
  // Facultad Regional Haedo
  //
  //   Copyright 2010 UTN FRH GSMC
  //   $Revision: //REV 1.1.5 2010/11/26 by MCR
  
  // ========================================================================
  // DATA MIGRATION AND GEOMETRIC AND MECHANICAL PROPERTIES COMPUTATION
  // ========================================================================
  // MCR: Equivalent for MATLAB syntax (>>format short g) not found
  // Disable vertical control paging
  lines(0)
  // File importation
  M=readxls(filename);
  // Table of nodes
  nodes=M(1);
  nn=max(nodes(:,1).value); 
  nod=nodes(3:2+nn,1:4);
  // Table of elements
  elements=M(2);
  ne=max(elements(:,1).value);
  elem=elements(4:3+ne,1:5);
  // Table of elements expansion
  E=elem(:,4);
  A=elem(:,5);
  elem(:,5)=[];
  elem(:,4)=[];
  // Elements geometric properties computation (L, cos(alpha), cos(beta),
  // cos(gamma))
  xf=nod(elem(:,3),2);
  x0=nod(elem(:,2),2);
  yf=nod(elem(:,3),3);
  y0=nod(elem(:,2),3);
  zf=nod(elem(:,3),4);
  z0=nod(elem(:,2),4);
  L=sqrt((xf-x0).^2+(yf-y0).^2+(zf-z0).^2);
  cos_alpha=(xf-x0)./L;
  cos_beta=(yf-y0)./L;
  cos_gamma=(zf-z0)./L;
  dircos=[cos_alpha,cos_beta,cos_gamma];
  // Compilation of table of elements
  elem=[elem,L,dircos,E,A];
  disp(' ') 
  disp('---> PROBLEM SIZE:')
  disp(['   - NUMBER OF NODES: ',string(nn)])
  disp(['   - NUMBER OF ELEMENTS: ',string(ne)])
  disp(' ')
endfunction
//Translated by AV 2010/11/08







