function [kL,B,T,kG] = stiffbar3d(E,A,L,dircos,ne)
// 1. Local stiffness matrix and deformation matrix (3d linear bar element formulation) 2. Transformation matrix of the element and global stiffness matrix (3D linear bar element formulation)
//Calling Sequence
// [kL, B, T, kG] = stiffbar3d(E, A, L, dircos, ne)
//
//Parameters
// INPUT ARGUMENTS:
// E: Modulus of elasticity [ne x 1]
// A: Cross-sectional Area [ne x 1]
// L: Bar length [ne x 1]
// dircos: Direction cosines [ne x 3]
// ne: Number of elements [1 x 1]
//
// OUTPUT ARGUMENTS:
// kL: Local stiffness matrix [ne*2 x 2]
// B: Deformation matrix [ne*1 x 2]
// T: Coordinates Transformation matrix [ne*2 x 6]
// kG: Global stiffness matrix [ne*6 x 6]
//
// See also
// assemb3d
// bc
// inpbar3d
// preplottruss3d
// postplottruss3d
// SPDsolve
// SPDverif
// stressbar3d
//
// Authors
// CEMEF-UTN v1.1-6
// Grupo de Simulacion y Mecanica Computacional
// Universidad Tecnologica Nacional
// Facultad Regional Haedo
//
// Copyright 2010 UTN FRH GSMC
// $Revision: //REV 1.1.7 2010/11/26 by MCR


  // STIFFBAR3D ---> 1. LOCAL STIFFNESS MATRIX AND DEFORMATION MATRIX 
  //                    (3D LINEAR BAR ELEMENT FORMULATION)
  //                 2. TRANSFORMATION MATRIX OF THE ELEMENT AND GLOBAL
  //                    STIFFNESS MATRIX
  //                    (3D LINEAR BAR ELEMENT FORMULATION)
  // 
  // SYNTAX:
  // [kL,B,T,kG]=stiffbar3d(E,A,L,dircos,ne)
  // - Type: Function
  //
  // INPUT ARGUMENTS:
  // - E: Modulus of elasticity [ne x 1]
  // - A: Cross-sectional Area [ne x 1]
  // - L: Bar length [ne x 1]
  // - dircos: Direction cosines [ne x 3]
  // - ne: Number of elements [1 x 1]
  //
  // OUTPUT ARGUMENTS:
  // - kL: Local stiffness matrix [ne*2 x 2]
  // - B: Deformation matrix [ne*1 x 2]
  // - T: Coordinates Transformation matrix [ne*2 x 6]
  // - kG: Global stiffness matrix [ne*6 x 6]
  //
  // CEMEF-UTN v1.1-6
  // Grupo de Simulacion y Mecanica Computacional
  // Universidad Tecnologica Nacional
  // Facultad Regional Haedo
  //
  //   Copyright 2010 UTN FRH GSMC
  //   $Revision: //REV 1.1.7 2010/11/26 by MCR
  
  // Preallocation of element matrices ONE BELOW THE OTHER
  // (Speed and optimization porpuses)
  kL=zeros(2*ne,2);
  B=zeros(1*ne,2);
  T=zeros(2*ne,6);
  kG=zeros(6*ne,6);
  for e=1:ne
    // =====================================================================
    // LOCAL STIFFNESS MATRIX AND DEFORMATION MATRIX (3D BAR ELEMENT
    // FORMULATION)
    // =====================================================================
    // First order element (Linear interpolation)
    // Local stiffness matrix of the element
    kL(2*e-1:2*e,:)=E(e)*A(e)/L(e)*[1,-1;-1,1]; 
    //Succession 1,3,5,...={2*e-1}
    // Deformation matrix of the element
    B(e,:)=[-1/L(e),1/L(e)]; 
    //Succession 1,2,3,...={e}
    // ======================================================================
    // TRANSFORMATION MATRIX OF THE ELEMENT AND GLOBAL STIFFNESS MATRIX
    // ======================================================================
    // Coordinates Transformation matrix of the element
    T(2*e-1:2*e,:)=[dircos(e,1),dircos(e,2),dircos(e,3),0,0,0;
    0,0,0,dircos(e,1),dircos(e,2),dircos(e,3)];
    // Global stiffness matrix of the element
    kG(6*e-5:6*e,:)=(T(2*e-1:2*e,:)')*kL(2*e-1:2*e,:)*T(2*e-1:2*e,:); 
    //Succession 1,7,13,...={6*e-5} //Modified by LBD 2010/10/09 
  end
endfunction
//Translated by SDL 2010/09/13

















