function [ue,sigma,f] = stressbar3d(E,A,B,T,tc,u0,ne)
// Coordinates transformation for stress computation on each bar element (return to element level formulation)
//Calling Sequence
// [ue, sigma, f] = stressbar3d(E, A, B, T, tc, u0, ne)
//
//Parameters
// INPUT ARGUMENTS:
// A: Cross-sectional Area [ne x 1]
// B: Deformation matrix [ne*1 x 2]
// T: Coordinates Transformation matrix [ne*2 x 6]
// tc: Table of connectivity [ne*DOFe x 3]
// u0: Complete nodal displacements vector [DOFn*nn x 1]
// ne: Number of nodes [1 x 1]
//
// OUTPUT ARGUMENTS:
// ue: Nodal displacements vector of the element in global coordinates [DOFe x 1]
// sigma: Normal stress vector [ne x 1]
// f: Normal loads vector [ne x 1]
//
// See also
// assemb3d
// bc
// inpbar3d
// preplottruss3d
// postplottruss3d
// SPDsolve
// SPDverif
// stiffbar3d
//
// Authors
// CEMEF-UTN v1.1-6
// Grupo de Simulacion y Mecanica Computacional
// Universidad Tecnologica Nacional
// Facultad Regional Haedo
//
// Copyright 2010 UTN FRH GSMC
// $Revision: //REV 1.1.1 2010/11/26 by MCR
    
  // STRESSBAR3D ---> COORDINATES TRANSFORMATION FOR STRESS COMPUTATION ON
  // EACH BAR ELEMENT (RETURN TO ELEMENT LEVEL FORMULATION)
  //
  // SYNTAX:
  // [ue,sigma,f]=stressbar3d(E,A,B,T,tc,u0,ne)
  // - Type: Function
  //
  // INPUT ARGUMENTS:
  // - E: Modulus of elasticity [ne x 1]
  // - A: Cross-sectional Area [ne x 1]
  // - B: Deformation matrix [ne*1 x 2]
  // - T: Coordinates Transformation matrix [ne*2 x 6]
  // - tc: Table of connectivity [ne*DOFe x 3]
  // - u0: Complete nodal displacements vector [DOFn*nn x 1]
  // - ne: Number of nodes [1 x 1]
  //
  // OUTPUT ARGUMENTS:
  // - ue: Nodal displacements vector of the element in global coordinates 
  //        [DOFe x 1]
  // - sigma: Normal stress vector [ne x 1]
  // - f: Normal loads vector [ne x 1]
  //
  // CEMEF-UTN v1.1-6
  // Grupo de Simulacion y Mecanica Computacional
  // Universidad Tecnologica Nacional
  // Facultad Regional Haedo
  //
  //   Copyright 2010 UTN FRH GSMC
  //   $Revision: //REV 1.1.1 2010/11/26 by MCR
  
  // =========================================================================
  // COORDINATES TRANSFORMATION: Nodal displacements vector and normal stress 
  // computation of each element (Return to element level formulation)
  // =========================================================================
  // Preallocation for speed and optimization porpuses
  sigma=zeros(ne,1);
  // Nodal displacements vector of the element in global coordinates
  ue=u0(tc(:,3));
  for e=1:ne
    // Normal stresses of each element
    sigma(e)=E(e)*B(e,:)*T(2*e-1:2*e,:)*ue(6*e-5:6*e);
  end
  // Normal loads vector of the structure
  f=A.*sigma;
endfunction







